@@ -2,45 +2,28 @@
   Hey,don't import me! I am for internal use.
 
   主要是用到的几个结构，包括学生信息、课程信息、成绩信息等等
+
   -------------------------------------
+
   Project Tongji-EasyAPI
   models.py
   Copyright (c) 2022 Cinea Zhan. All rights reserved
   www.cinea.com.cn
 """
 
+from collections import namedtuple
 
-class Student:
-    """
-    学生信息类型，推荐用户使用
-    """
 
-    def __init__(self, name="", studentId="", sex=0, faculty="", facultyName="", grade="",
-                 studentDataObject=None) -> None:
-        self.sourceObj = None
-        if studentDataObject:
-            self.sourceObj = studentDataObject
-            try:
-                name = studentDataObject["name"]
-                studentId = studentDataObject["uid"]
-                sex = studentDataObject["sex"]
-                faculty = studentDataObject["faculty"]
-                facultyName = studentDataObject["facultyName"]
-                grade = studentDataObject["grade"]
-            except KeyError:
-                raise ValueError("您传入的数据不正确，若您没有来自1系统的user对象，则请您不要传入此参数。")
-        self.name = name
-        self.studentId = studentId
-        self.sex = sex
-        self.faculty = faculty
-        self.facultyName = facultyName
-        self.grade = grade
+Student = namedtuple('Student', ['name', 'studentId', 'sex', 'faculty', 'facultyName', 'grade'])
+"""
+  学生信息具名元组。
+"""
 
-    def __str__(self) -> str:
-        return f"<{self.name},{self.studentId},{self.facultyName},{self.grade}级>"
-
-    def __repr__(self) -> str:
-        return str(self)
+electRound = namedtuple("electRound", ["id", "name", "isOpen", "beginTime", "endTime", "createdTime", "updateTime",
+                                       "remark", "calendarId", "calendarName"])
+"""
+  选课信息具名元组。
+"""
 
 
 class Scores:
@@ -70,7 +53,10 @@ class Scores:
             self.earnedCredits = sd["actualCredit"]  # 已修读学分
             self.failedCredits = sd["failingCredits"]  # 不及格学分
             self.failedNum = sd["failingCourseCount"]  # 不及格门数
-            self.termNum = len(sd["term"])  # 学期数量
+            try:
+                self.termNum = len(sd["term"])  # 学期数量
+            except TypeError as e:
+                self.termNum = 0                # 学期数量
             self.coursesList = []  # 课程列表
 
             courseNum = 0
@@ -90,7 +76,7 @@ class Scores:
 
             # 更多功能，发issue，都可以加！
 
-        except KeyError as e:
+        except KeyError or TypeError as e:
             raise ValueError("传入的内容不能被正确解析，请检查是否完整、正确传入, 错误信息：" + str(e))
 
     def __str__(self):
